==> blesta-5.10.2.zip: blesta/plugins/order/views/templates/standard/language/tr_tr/domain.php <==
<?php
/**
 * Domain
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Domain.lookup.term_onetime'] = '1$s @ %2$s';
$lang['Domain.lookup.term_recurring'] = '1$s %2$s @ %3$s (%4$s\'de yenilenir)';
$lang['Domain.lookup.term'] = '1$s %2$s @ %3$s';
$lang['Domain.lookup.order_btn'] = 'Sipariş Seçildi';
$lang['Domain.lookup.term_years'] = '1$s Yıl';
$lang['Domain.lookup.term_year'] = '1$s Yıl';
$lang['Domain.lookup.term_months'] = '1$s Ay';
$lang['Domain.lookup.term_month'] = '1$s Ay';
$lang['Domain.lookup.term_weeks'] = '1$s Haftalar';
$lang['Domain.lookup.term_week'] = '1$s Hafta';
$lang['Domain.lookup.term_days'] = '1$s Gün';
$lang['Domain.lookup.term_day'] = '1$s Günü';
$lang['Domain.lookup.heading_renew_price'] = 'Yenileme Fiyatı';
$lang['Domain.lookup.heading_transfer_price'] = 'Transfer Fiyatı';
$lang['Domain.lookup.heading_price'] = 'Fiyat';
$lang['Domain.lookup.heading_tld'] = 'TLD';
$lang['Domain.lookup.domain_eligible_free'] = '1$s Ücretsiz için Uygun';
$lang['Domain.lookup.domain_unavailable'] = 'Mevcut değil';
$lang['Domain.lookup.domain_available'] = 'Mevcut';
$lang['Domain.lookup.domains_term'] = 'Dönem';
$lang['Domain.lookup.domains_status'] = 'Durum';
$lang['Domain.lookup.domains_domain_name'] = 'Alan Adı';
$lang['Domain.lookup.domains_header_free'] = 'Alan adı, aşağıdaki paket gruplarından herhangi birinden bir paketle birlikte en az %1$s: %2$s karşılığında ücretsiz olabilir.';
$lang['Domain.lookup.domains_header_unavailable'] = 'Üzgünüz, bu alan adı mevcut değil.';
$lang['Domain.lookup.domains_header_available'] = 'Tebrikler, bu alan kullanılabilir durumda.';
$lang['Domain.lookup.other_btn'] = 'Diğer Ürünleri Sipariş Edin';
$lang['Domain.lookup.lookup_btn'] = 'Müsaitliği Kontrol Edin';
$lang['Domain.lookup.transfer_btn'] = 'Transfer';
$lang['Domain.lookup.loading'] = 'Yükleniyor...';
$lang['Domain.lookup.hide_all'] = 'Tümünü Gizle';
$lang['Domain.lookup.show_all'] = 'Tümünü Göster';
$lang['Domain.lookup.domain_placeholder'] = 'yourdomain.com';
$lang['Domain.lookup.title'] = 'Alan Adı Kullanılabilirliğini Kontrol Edin';

==> blesta-5.11.4.zip: blesta/plugins/order/views/templates/standard/language/tr_tr/domain.php <==
<?php
/**
 * Domain
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Domain.lookup.order_btn'] = 'Sipariş Seçildi';
$lang['Domain.lookup.heading_renew_price'] = 'Yenileme Fiyatı';
$lang['Domain.lookup.heading_transfer_price'] = 'Transfer Fiyatı';
$lang['Domain.lookup.heading_price'] = 'Fiyat';
$lang['Domain.lookup.heading_tld'] = 'TLD';
$lang['Domain.lookup.domain_unavailable'] = 'Mevcut değil';
$lang['Domain.lookup.domain_available'] = 'Mevcut';
$lang['Domain.lookup.domains_term'] = 'Dönem';
$lang['Domain.lookup.domains_status'] = 'Durum';
$lang['Domain.lookup.domains_domain_name'] = 'Alan Adı';
$lang['Domain.lookup.domains_header_free'] = 'Alan adı, aşağıdaki paket gruplarından herhangi birinden bir paketle birlikte en az %1$s: %2$s karşılığında ücretsiz olabilir.';
$lang['Domain.lookup.domains_header_unavailable'] = 'Üzgünüz, bu alan adı mevcut değil.';
$lang['Domain.lookup.domains_header_available'] = 'Tebrikler, bu alan kullanılabilir durumda.';
$lang['Domain.lookup.other_btn'] = 'Diğer Ürünleri Sipariş Edin';
$lang['Domain.lookup.lookup_btn'] = 'Müsaitliği Kontrol Edin';
$lang['Domain.lookup.transfer_btn'] = 'Transfer';
$lang['Domain.lookup.loading'] = 'Yükleniyor...';
$lang['Domain.lookup.hide_all'] = 'Tümünü Gizle';
$lang['Domain.lookup.show_all'] = 'Tümünü Göster';
$lang['Domain.lookup.domain_placeholder'] = 'yourdomain.com';
$lang['Domain.lookup.title'] = 'Alan Adı Kullanılabilirliğini Kontrol Edin';
$lang['Domain.lookup.term_onetime'] = '%1$s @ %2$s';
$lang['Domain.lookup.term_recurring'] = '%1$s %2$s @ %3$s (%4$s tarihinde yenilenir)';
$lang['Domain.lookup.term'] = '%1$s %2$s @ %3$s';
$lang['Domain.lookup.term_years'] = '%1$s Yıllar';
$lang['Domain.lookup.term_year'] = '%1$s Yıl';
$lang['Domain.lookup.term_months'] = '%1$s Aylar';
$lang['Domain.lookup.term_month'] = '%1$s Ay';
$lang['Domain.lookup.term_weeks'] = '%1$s Haftalar';
$lang['Domain.lookup.term_week'] = '%1$s Hafta';
$lang['Domain.lookup.term_days'] = '%1$s Günler';
$lang['Domain.lookup.term_day'] = '%1$s Gün';
$lang['Domain.lookup.domain_eligible_free'] = '%1$s Ücretsiz için uygun';
